package com.huimv.produce.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.common.utils.DataUill;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import com.huimv.produce.entity.BaseRoom;
import com.huimv.produce.entity.SysFodder;
import com.huimv.produce.entity.SysHumidity;
import com.huimv.produce.entity.SysTemperature;
import com.huimv.produce.entity.dto.AllRoomEnvironment;
import com.huimv.produce.entity.dto.ScreenDto;
import com.huimv.produce.mapper.BaseRoomMapper;
import com.huimv.produce.mapper.SysFodderMapper;
import com.huimv.produce.mapper.SysHumidityMapper;
import com.huimv.produce.mapper.SysTemperatureMapper;
import com.huimv.produce.service.IBaseRoomService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author astupidcoder
 * @since 2021-11-11
 */
@Service
public class BaseRoomServiceImpl extends ServiceImpl<BaseRoomMapper, BaseRoom> implements IBaseRoomService {

    @Autowired
    private SysHumidityMapper humidityMapper;

    @Autowired
    private SysTemperatureMapper temperatureMapper;

    @Autowired
    private SysFodderMapper fodderMapper;

    @Autowired
    private BaseRoomMapper baseRoomMapper;


    @Override
    public Result getAllRoomEnvironment(Integer farmId) {

       List<AllRoomEnvironment> list =  baseRoomMapper.getAllRoomEnvironment(farmId);

        return new Result(ResultCode.SUCCESS,list);
    }

    @Override
    public Result listByRoom(Map<String,String> map) {
        String roomId = map.get("roomId");
        String startDate = map.get("startDate");
        String endDate = map.get("endDate");
        String type = map.get("type");
        String farmId = map.get("farmId");


        BaseRoom baseRoom = new BaseRoom();
        if (StrUtil.isBlank(roomId)){
//            baseRoom =  this.getOne(new QueryWrapper<BaseRoom>().eq("farm_id",farmId).last("limit 1"));
//            roomId = baseRoom.getId()+"";
            roomId ="157";
            baseRoom =this.getById(roomId);
        }else {
            baseRoom =this.getById(roomId);
        }

        QueryWrapper<SysHumidity> humidityWrapper = new QueryWrapper<>();
        QueryWrapper<SysTemperature> temperatureWrapper = new QueryWrapper<>();
        humidityWrapper.eq("room_id",roomId);
        temperatureWrapper.eq("room_id",roomId);

        List<SysHumidity> humidities;
        List<SysTemperature> semperatures;
        //根据自定义
        Map resultMap = new HashMap<>();
        if ("4".equals(type) ){
            humidityWrapper.between("create_time", startDate, endDate);
            temperatureWrapper.between("create_time", startDate, endDate);

            humidities =   humidityMapper.listDay(humidityWrapper);
            semperatures =   temperatureMapper.listDay(temperatureWrapper);


            resultMap.put("humidities",humidities);
            resultMap.put("semperatures",semperatures);
        }

        //本月
        else if ("3".equals(type)){
            Date timesMonthmorning = DataUill.getTimesMonthmorning();
            humidityWrapper.ge("create_time",timesMonthmorning );
            temperatureWrapper.ge("create_time", timesMonthmorning);
            humidities =   humidityMapper.listDay(humidityWrapper);
            semperatures =   temperatureMapper.listDay(temperatureWrapper);

            resultMap.put("humidities",humidities);
            resultMap.put("semperatures",semperatures);
        }
        //本周
        else if ("2".equals(type)){
            Date timesWeekmorning = DateUtil.beginOfWeek(new Date());
            humidityWrapper.ge("create_time",timesWeekmorning );
            temperatureWrapper.ge("create_time", timesWeekmorning);
            humidities =   humidityMapper.listDay(humidityWrapper);
            semperatures =   temperatureMapper.listDay(temperatureWrapper);

            resultMap.put("humidities",humidities);
            resultMap.put("semperatures",semperatures);
        }
        //今日
        else {
            Date timesmorning = DataUill.getTimesmorning();
            humidities = humidityMapper.selectList(humidityWrapper.ge("create_time",timesmorning ));
            semperatures = temperatureMapper.selectList(temperatureWrapper.ge("create_time", timesmorning));
            resultMap.put("humidities",humidities);
            resultMap.put("semperatures",semperatures);
        }

        resultMap.put("roomName",baseRoom.getAlias()+baseRoom.getRoomName());
//        if ("1".equals(isExcel)){
//            writerExcel(humidities,"温度曲线");
//        }

        return new Result(ResultCode.SUCCESS,resultMap);
    }

    @Override
    public Result listLargeScreen(String farmId) {
        ScreenDto screenDto =  fodderMapper.fodderMapper();
        return new Result(ResultCode.SUCCESS,screenDto);

    }

//    private void writerExcel(List list,String title) {
//        ExcelWriter writer = ExcelUtil.getWriter("C:\\Users\\Administrator\\Desktop\\writeBeanTest.xlsx");
//        writer.merge(4, title);
//
//        writer.write(list, true);
//        writer.close();
//    }
}
